//
// ETSI (European Telecommunications Standards Institute, referred to as ETSI)
// ARF - ETSI ISG Augmented Reality Framework (ISG ARF)
// (C) 2022
//
// Development "World Storage", data management, authoring tools
//
// Authors:
// - Sylvain Renault (Fraunhofer HHI)
// 
// Date: Feb. 2022
//

using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEditor;

namespace ETSI.ARF.WorldStorage.UI
{
    [CustomEditor(typeof(WorldStorageServer))]
    public class WorldStorageServerEditor : Editor
    {
        WorldStorageServer worldStorageServer;
        WorldStorageWindow win;

        public void OnEnable()
        {
            worldStorageServer = (WorldStorageServer)target;
        }

        public override void OnInspectorGUI()
        {
            serializedObject.Update();

            Color ori = GUI.backgroundColor;

            GUILayout.Label("Copyright(c) 2022, ETSI - ARF");
            EditorGUILayout.Space();
            GUILayout.Label("Parameters:", EditorStyles.boldLabel);
            DrawDefaultInspector();
            EditorGUILayout.Space();

            // open window button
            GUI.backgroundColor = WorldStorageWindow.arfColors[1];
            if (GUILayout.Button("Open World Storage Window..."))
            {
                Debug.Log("Open Main ARF Window");
                win = EditorWindow.GetWindow(typeof(WorldStorageWindow), false, "ETSI ARF - Authoring Editor") as WorldStorageWindow;
                win.worldStorageServer = worldStorageServer;
                win.worldStorageUser = worldStorageServer.user;
            }
            GUI.backgroundColor = ori;
        }
    }
}